@@ -1,7 +1,7 @@
 package Evo::Class::T;
 use Evo '-Export *; Carp croak; List::Util any';
 
-sub t_enum(@list) : Export {
+sub T_ENUM(@list) : Export {
   croak "empty enum list" unless @list;
   sub($v) {
     any { defined $v ? defined $_ ? $_ eq $v : !defined $v : !defined $_ } @list;
@@ -22,7 +22,7 @@ Evo::Class::T
 
 =head1 VERSION
 
-version 0.0225
+version 0.0231
 
 =head1 DESCRIPTION
 
@@ -34,7 +34,7 @@ Types for L<Evo::Class/"check">. Right now there aren't so many of them.
 
     package My::Foo;
     use Evo -Class, '-Class::T *';
-    has status => check => t_enum("ok", "not ok");
+    has status => check => T_ENUM("ok", "not ok");
 
   }
 
@@ -43,9 +43,9 @@ Types for L<Evo::Class/"check">. Right now there aren't so many of them.
 
 =head1 FUNCTIONS
 
-=head2 t_enum
+=head2 T_ENUM
 
-  my $check = t_enum("ok", "good");
+  my $check = T_ENUM("ok", "good");
   my($ok, $err) = $check->("bad");
 
 Enum checker - a value must be one of the list;
